# Usage

## Angular integration
**TODO**: document the usage of the `ngx_core` library.

```dart
import 'package:ngx_core/ngx_core.dart';
```

## JavaScript interoperability
The `ngx_core.js` library provides interoperability with the [JavaScript](https://developer.mozilla.org/en-US/docs/Web/JavaScript) APIs, and helper functions for converting or inspecting objects.

```dart
import 'package:ngx_core/js.dart';
```

The library exports these functions from the `dart:js_util` library:

- `callConstructor()`
- `callMethod()`
- `getProperty()`
- `hasProperty()`
- `instanceof()`
- `jsify()`
- `newObject()`
- `setProperty()`

It also provides the following `global` property and helper functions.

### dynamic get **global**
An object representing the global namespace. It is a proxy to the native `self` object:

```dart
import 'package:ngx_core/js.dart';

void main() {
  var constructor = getProperty(global, 'constructor');
  print(getProperty(constructor, 'name')); // "Window"
  
  print(hasProperty(global, 'fooBar')); // false
  setProperty(global, 'fooBar', 'bazQux');
  print(getProperty(global, 'fooBar')); // "bazQux"
}
```

### dynamic **dartify**(Object value)
Recursively converts a JavaScript value to a Dart object:

```dart
import 'package:ngx_core/js.dart';

void main() {
  var jsArray = jsify(['foo', 'bar', {'baz': 'qux'}]);
  var dartList = dartify(jsArray);

  print(dartList is List); // true
  print(dartList.first is String); // true
  print(dartList.last is Map); // true

  var jsObject = jsify({'foo': 'bar', 'baz': ['qux']});
  var dartMap = dartify(jsObject);

  print(dartMap is Map); // true
  print(dartMap.values.first is String); // true
  print(dartMap.values.last is List); // true
}
```

### bool **deleteProperty**(Object object, Object propertyKey)
Removes a property from a JavaScript object:

```dart
import 'package:ngx_core/js.dart';

void main() {
  var jsObject = jsify({'foo': 'bar'});
  print(hasProperty(jsObject, 'foo')); // true

  deleteProperty(jsObject, 'foo');
  print(hasProperty(jsObject, 'foo')); // false
}
```

### Map **getProperties**(Object object)
Returns a map of the own enumerable properties of a JavaScript object:

```dart
import 'package:ngx_core/js.dart';

void main() {
  var jsObject = jsify({'foo': 'bar'});
  var properties = getProperties(jsObject);
  print(properties.keys.single); // "foo"
  print(properties['foo']); // "bar"
}
```
