part of ngx_core;

/// Navigates to the previous page in the session history when the underlying control is clicked.
@Directive(
  exportAs: 'goBack',
  selector: '[goBack]'
)
class GoBack {

  /// The service providing access to the browser's URL.
  final Location _location;

  /// The routing service.
  final Router _router;

  /// The service providing access to the browser's window.
  // v5 final dom.Window _window;

  /// Creates a new `goBack` directive.
  GoBack(this._location, this._router, /* v5: this._window */);

  /// Value indicating whether a previous page in navigation history is available.
  bool get canGoBack => dom.window.history.length > 2;

  /// The route to be used when the session history is empty.
  @Input('goBack')
  List fallbackRoute = const [];
  // v5: String fallbackRoute; // TODO: fallbackPath + fallbackParams? fallbackRoutePath?

  /// Navigates to the previous page in the session history if any, otherwise navigates to the [fallbackRoute].
  @HostListener('click')
  void onClick() {
    if (canGoBack) _location.back();
    else if (fallbackRoute.isNotEmpty) _router.navigate(fallbackRoute);
    else _router.navigateByUrl('/');
    // v5: else _router.navigate('/');
  }
}
